@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.66 2012/02/06 22:07:09 espie Exp $
+# $OpenBSD: Quirks.pm,v 1.80 2012/06/16 12:52:04 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -92,6 +92,8 @@ my $base_exceptions = {
 # 4.9
 	'video' => "/usr/X11R6/bin/video",
 	'nsd' => "/usr/sbin/nsd",
+# 5.2
+	'sqlite3' => '/usr/bin/sqlite3',
 };
 
 my $stem_extensions = {
@@ -279,6 +281,26 @@ my $stem_extensions = {
 	'aspell5-tn' => 'aspell-tn',
 	'aspell6-uk' => 'aspell-uk',
 	'vte-ptyhelper' => 'vte',
+# 5.2
+	'gpsbabel-gui' => 'gpsbabel-tk',
+	'gnome-extras' => 'gnome-extra',
+	'maatkit' => 'percona-toolkit',
+	'scrotwm' => 'spectrwm',
+	'gnuls' => 'coreutils',
+	'sh-utils' => 'coreutils',
+	'fileutils' => 'coreutils',
+	'textutils' => 'coreutils',
+	'gnome-utils' => 'gnome-search-tool',
+	'seahorse-plugins' => 'seahorse-nautilus',
+	'apr-mt' => 'apr',
+	'apr-util-mt' => 'apr-util',
+	'xfce-utils' => 'xfce4-session',
+	'p5-Email-MIME-Creator' => 'p5-Email-MIME',
+	'p5-Email-MIME-Modifier' => 'p5-Email-MIME',
+	'libmpcdec' => 'musepack',
+	'mppenc' => 'musepack',
+	'xxxterm' => 'xombrero',
+	'pecl-zip' => 'php-zip'
 };
 
 # ->is_base_system($handle, $state):
